pub struct BasicNode {
pub addr: String,
}Expand description
An implementation of trait Node that contains minimal node information.
The most common usage is to store the connecting address of a node.
So that an application does not need an additional store to support its
RaftNetwork implementation.
An application is also free not to use this storage and implements its own node-id to address mapping.
Fields
addr: StringUser defined string that represent the endpoint of the target node.
It is used by RaftNetwork for connecting to target node.
Implementations