pub struct MemberState {
pub id: NodeId,
pub addr: SocketAddr,
pub incarnation: u64,
pub state: MemberStatus,
pub state_change: Instant,
pub is_primary: bool,
pub replicates: Option<NodeId>,
pub slots: Vec<SlotRange>,
}Expand description
Internal state of a cluster member as tracked by gossip.
Fields
id: NodeIdaddr: SocketAddrincarnation: u64state: MemberStatusstate_change: Instantis_primary: boolreplicates: Option<NodeId>The primary this member replicates from, if it is a replica.
slots: Vec<SlotRange>Trait Implementations
Sourceimpl Clone for MemberState
impl Clone for MemberState
Sourcefn clone(&self) -> MemberState
fn clone(&self) -> MemberState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for MemberState
impl RefUnwindSafe for MemberState
impl Send for MemberState
impl Sync for MemberState
impl Unpin for MemberState
impl UnsafeUnpin for MemberState
impl UnwindSafe for MemberState